@@ -1,3 +1,4 @@
+from python_helper import log
 from globals import getGlobalsInstance
 globalsInstance = getGlobalsInstance()
 
@@ -5,9 +6,10 @@ try:
     from constant import NotificationConfigurationKeyConstant
 except:
     try:
-        from notification_manager_api import NotificationConfigurationKeyConstant
-    except:
         from notification_manager_api.api.src.constant import NotificationConfigurationKeyConstant
+    except Exception as exception:
+        log.warning(log.warning, 'There are most likely an issue related to queue-manager-api dependencies imports', exception=exception)
+        from notification_manager_api import NotificationConfigurationKeyConstant
 
 
 QUEUE_KEY = globalsInstance.getSetting(NotificationConfigurationKeyConstant.QUEUE_KEY)
