@@ -1,3 +1,4 @@
+from python_helper import log
 from python_framework import Serializer
 
 try:
@@ -6,13 +7,14 @@ try:
     from enumeration.NotificationDestiny import NotificationDestiny
 except:
     try:
-        from notification_manager_api import NotificationSeverity
-        from notification_manager_api import NotificationStatus
-        from notification_manager_api import NotificationDestiny
-    except:
         from notification_manager_api.api.src.enumeration.NotificationSeverity import NotificationSeverity
         from notification_manager_api.api.src.enumeration.NotificationStatus import NotificationStatus
         from notification_manager_api.api.src.enumeration.NotificationDestiny import NotificationDestiny
+    except Exception as exception:
+        log.warning(log.warning, 'There are most likely an issue related to queue-manager-api dependencies imports', exception=exception)
+        from notification_manager_api import NotificationSeverity
+        from notification_manager_api import NotificationStatus
+        from notification_manager_api import NotificationDestiny
 
 
 DEFAULT_MESSAGE = 'No message was sent'
