@@ -1,10 +1,13 @@
+from python_helper import log
+
 try:
     from converter.static import NotificationStaticConverter
 except:
     try:
-        from notification_manager_api import NotificationStaticConverter
-    except:
         from notification_manager_api.api.src.converter.static import NotificationStaticConverter
+    except Exception as exception:
+        log.warning(log.warning, 'There are most likely an issue related to queue-manager-api dependencies imports', exception=exception)
+        from notification_manager_api import NotificationStaticConverter
 
 
 class NotificationRequestDto:
